==> gnome-python-1.0.2.tar.gz: gnome-python-1.0.2/pygnome/mkgnome.py <==
import sys

sys.path.insert(0, "../pygtk/generate")
import generate

print "Reading gtk's object and enum definitions ...",
sys.stdout.flush()
generate.TypesParser('../pygtk/generate/gtk.defs').startParsing()
print "done"

print "Outputing zvt stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/zvt.defs',
			     prefix='zvtmodule')
p.addExcludeFile('generate/zvt.ignore')
p.startParsing()
print "done"

print "Outputing xmhtml stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/xmhtml.defs',
			     prefix='gtkxmhtmlmodule')
p.addExcludeFile('generate/xmhtml.ignore')
p.startParsing()
print "done"

print "Outputing gnome stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/gnome.defs',
			     prefix='gnomemodule')
p.addExcludeFile('generate/gnome.ignore')
p.startParsing()
print "done"

print "Outputing gnomeui stuff ...",
sys.stdout.flush()
generate.boxed['GdkImlibImage'] = ('PyGdkImlibImage_Type',
				   'PyGdkImlibImage_Get',
				   'PyGdkImlibImage_New')
p = generate.FilteringParser(input='generate/gnomeui.defs',
			     prefix='gnomeuimodule')
p.addExcludeFile('generate/gnomeui.ignore')
p.startParsing()
print "done"

print "Outputing applet stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/applet.defs',
			     prefix='appletmodule')
p.startParsing()
print "done"

print "Outputing capplet stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/capplet.defs',
			     prefix='cappletmodule')
p.startParsing()
print "done"

==> gnome-python-1.0.4.tar.gz: gnome-python-1.0.4/pygnome/mkgnome.py <==
import sys

sys.path.insert(0, "../pygtk/generate")
import generate

print "Reading gtk's object and enum definitions ...",
sys.stdout.flush()
generate.TypesParser('../pygtk/generate/gtk.defs').startParsing()
print "done"

print "Outputing zvt stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/zvt.defs',
			     prefix='zvtmodule',
			     typeprefix='&')
p.addExcludeFile('generate/zvt.ignore')
p.startParsing()
print "done"

print "Outputing xmhtml stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/xmhtml.defs',
			     prefix='gtkxmhtmlmodule',
			     typeprefix='&')
p.addExcludeFile('generate/xmhtml.ignore')
p.startParsing()
print "done"

print "Outputing gnome stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/gnome.defs',
			     prefix='gnomemodule')
p.addExcludeFile('generate/gnome.ignore')
p.startParsing()
print "done"

print "Outputing gnomeui stuff ...",
sys.stdout.flush()
generate.boxed['GdkImlibImage'] = ('PyGdkImlibImage_Type',
				   'PyGdkImlibImage_Get',
				   'PyGdkImlibImage_New')
p = generate.FilteringParser(input='generate/gnomeui.defs',
			     prefix='gnomeuimodule',
			     typeprefix='&')
p.addExcludeFile('generate/gnomeui.ignore')
p.startParsing()
print "done"

print "Outputing applet stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/applet.defs',
			     prefix='appletmodule',
			     typeprefix='&')
p.startParsing()
print "done"

print "Outputing capplet stuff ...",
sys.stdout.flush()
p = generate.FilteringParser(input='generate/capplet.defs',
			     prefix='cappletmodule',
			     typeprefix='&')
p.startParsing()
print "done"
